"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isTrue = isTrue;
const core_1 = require("@serenity-js/core");
const equals_1 = require("./equals");
/**
 * Creates an [expectation](https://serenity-js.org/api/core/class/Expectation/) that is met when the actual `boolean` value
 * is `true`.
 *
 * ## Ensuring that a given value is true
 *
 * ```ts
 * import { actorCalled } from '@serenity-js/core'
 * import { Ensure, isTrue } from '@serenity-js/assertions'
 * import { Cookie } from '@serenity-js/web'
 *
 * await actorCalled('Ester').attemptsTo(
 *   Ensure.that(Cookie.called('example-secure-cookie').isSecure(), isTrue()),
 * )
 * ```
 *
 * @group Expectations
 */
function isTrue() {
    return core_1.Expectation.to(`equal true`).soThatActual((0, equals_1.equals)(true));
}
//# sourceMappingURL=isTrue.js.map