import { Expectation } from '@serenity-js/core';
/**
 * Creates an [expectation](https://serenity-js.org/api/core/class/Expectation/) that is met when at least one of the `expectations` is met for the given actual value.
 *
 * Use `or` to combine several expectations using logical "or",
 *
 * ## Combining several expectations
 *
 * ```ts
 * import { actorCalled } from '@serenity-js/core'
 * import { Ensure, or, startsWith } from '@serenity-js/assertions'
 *
 * await actorCalled('Ester').attemptsTo(
 *   Ensure.that('Hello World!', or(startsWith('Hello'), startsWith('Hi'))),
 * )
 * ```
 *
 * @param expectations
 *
 * @group Expectations
 */
export declare function or<Actual_Type>(...expectations: Array<Expectation<Actual_Type>>): Expectation<Actual_Type>;
//# sourceMappingURL=or.d.ts.map